==> payara-embedded-web-4.1.2.172-sources.jar: org/glassfish/webservices/SecurityService.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.webservices;

import com.sun.enterprise.deployment.ServiceReferenceDescriptor;
import com.sun.enterprise.deployment.WebServiceEndpoint;
import com.sun.enterprise.deployment.runtime.common.MessageSecurityBindingDescriptor;
import com.sun.enterprise.web.WebModule;
import com.sun.xml.rpc.spi.runtime.SystemHandlerDelegate;
import javax.servlet.http.HttpServletRequest;
import com.sun.xml.rpc.spi.runtime.SOAPMessageContext;
import com.sun.xml.rpc.spi.runtime.StreamingHandler;
import com.sun.xml.ws.assembler.ClientPipelineHook;
import java.security.Principal;
import javax.xml.namespace.QName;
import javax.xml.rpc.handler.HandlerInfo;
import org.jvnet.hk2.annotations.Contract;

/**
 *
 * @author Kumar
 */
@Contract
public interface SecurityService {
    
    public Object mergeSOAPMessageSecurityPolicies(MessageSecurityBindingDescriptor desc);
    public boolean doSecurity(HttpServletRequest hreq, EjbRuntimeEndpointInfo ejbEndpoint, String realmName, WebServiceContextImpl context);
    public void resetSecurityContext();
    public void resetPolicyContext();
    public SystemHandlerDelegate getSecurityHandler(WebServiceEndpoint endpoint);
    public boolean validateRequest(Object serverAuthConfig, StreamingHandler implementor, SOAPMessageContext context);
    public void secureResponse(Object serverAuthConfig, StreamingHandler implementor, SOAPMessageContext context);
    public HandlerInfo getMessageSecurityHandler(MessageSecurityBindingDescriptor binding, QName serviceName);
    public ClientPipelineHook getClientPipelineHook(ServiceReferenceDescriptor ref);
    public Principal getUserPrincipal(boolean isWeb);
    public boolean isUserInRole(WebModule webModule, Principal principal, String servletName, String role);
}

==> payara-embedded-web-6.2023.12-sources.jar: org/glassfish/webservices/SecurityService.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018-2021] [Payara Foundation and/or its affiliates]
package org.glassfish.webservices;

import com.sun.enterprise.deployment.ServiceReferenceDescriptor;
import com.sun.enterprise.deployment.runtime.common.MessageSecurityBindingDescriptor;
import com.sun.enterprise.web.WebModule;
import com.sun.xml.ws.assembler.metro.dev.ClientPipelineHook;
import jakarta.servlet.http.HttpServletRequest;
import org.jvnet.hk2.annotations.Contract;

import java.security.Principal;

/**
 *
 * @author Kumar
 */
@Contract
public interface SecurityService {

    Object mergeSOAPMessageSecurityPolicies(MessageSecurityBindingDescriptor desc);

    boolean doSecurity(HttpServletRequest hreq, EjbRuntimeEndpointInfo ejbEndpoint, String realmName, WebServiceContextImpl context);

    Principal getUserPrincipal(boolean isWeb);

    boolean isUserInRole(WebModule webModule, Principal principal, String servletName, String role);

    void resetSecurityContext();

    void resetPolicyContext();

    ClientPipelineHook getClientPipelineHook(ServiceReferenceDescriptor ref);
}
